==> stimulsoft-viewer-angular-2022.3.4.tgz: package/README.md <==
# **Angular component for Stimulsoft Reports**


The Viewer component is designed to view reports in the web browser.

With help of Viewer, you can view, print and export reports on any computer with any operating system installed. Support tablets and smartphones. Also, the viewer supports Mobile interfaces, which automatically enable when using mobile devices and touch screen monitors.

Viewer supports many themes, animated interface, bookmarks, interactive reports, editing of report elements on the page, full screen mode, search panel, and other necessary features for viewing reports.

More about [Stimulsoft Reports.Angular](https://www.stimulsoft.com/en/products/reports-angular)

# How to install

```
npm install stimulsoft-viewer-angular
```
# Integration

Stimulsoft Reports.Angular is designed to run in an Angular application with ASP.NET MVC or .NET Core frameworks. For the convenience of integrating the report into the project, a publishing wizard is available.

To integrate the product into the project, it is enough to install the necessary packages from the NPM repository for the Angular project, and one package from the [NuGet repository](https://www.nuget.org/packages/Stimulsoft.Reports.Angular) on the server-side for the required platform. If necessary, all packages can be downloaded from our website to a computer and manually add libraries and scripts to the project. No additional modules or special extensions are required, everything you need you can find in the product

# Live Demo

We prepared many templates of reports and dashboards, that you can explore and edit in our online demo. Choose the template you need, connect your data and try to create rich reports and analytical dashboards – the solution is ready. Try the [**Live Demo**](http://demo.stimulsoft.com/#Js).

# Video and Documentation

We provide full User Manuals and Class References intended to give technical assistance to people using our reporting tools. More information in the [**Online Documentation**](https://www.stimulsoft.com/en/documentation/online/programming-manual/index.html?reports_js.htm)**.**

Also, we prepared many videos about working of our software. See video on our **YouTube channel**.

[**Download**](https://www.stimulsoft.com/en/downloads)

[**Online Store**](https://www.stimulsoft.com/en/# **Angular component for Stimulsoft Reports**

The Angular Designer component is designed to create reports in the web browser.

With help of Angular Designer you can create, edit, save and preview reports on any computer with any operating system installed. Since the designer only uses HTML and JavaScript technologies, it can be run on devices where there is no Flash or Silverlight support - tablets, smartphones. Also, the designer supports the Touch interface, which is automatically enabled when using devices with a touch screen.

The Angular Designer component uses the AJAX technology to perform all actions on reports, which allows you to get rid of reloading the entire page, save Web traffic and speed up work. The report engine built using the .NET Core technology is used to render reports. This is a cross-platform technology. It allows you to deploy the application on servers that use the operating systems like Windows, macOS, and Linux.

More about [Stimulsoft Reports.Angular](https://www.stimulsoft.com/en/products/reports-angular)

# How to install

```
npm install stimulsoft-designer-angular
```
# Integration

Stimulsoft Reports.Angular is designed to run in an Angular application with ASP.NET MVC or .NET Core frameworks. For the convenience of integrating the report into the project, a publishing wizard is available.

To integrate the product into the project, it is enough to install the necessary packages from the NPM repository for the Angular project, and one package from the [NuGet repository](https://www.nuget.org/packages/Stimulsoft.Reports.Angular) on the server-side for the required platform. If necessary, all packages can be downloaded from our website to a computer and manually add libraries and scripts to the project. No additional modules or special extensions are required, everything you need you can find in the product

# Live Demo

We prepared many templates of reports and dashboards, that you can explore and edit in our online demo. Choose the template you need, connect your data and try to create rich reports and analytical dashboards – the solution is ready. Try the [**Live Demo**](http://demo.stimulsoft.com/#Js).

# Video and Documentation

We provide full User Manuals and Class References intended to give technical assistance to people using our reporting tools. More information in the [**Online Documentation**](https://www.stimulsoft.com/en/documentation/online/programming-manual/index.html?reports_js.htm)**.**

Also, we prepared many videos about working of our software. See video on our **YouTube channel**.

[**Download**](https://www.stimulsoft.com/en/downloads)

[**Online Store**](https://www.stimulsoft.com/en/online-store)

[**License Info**](https://github.com/stimulsoft/Reports.JS/blob/HEAD/LICENSE.md)


# Keywords


- **Stimulsoft**
-   **Reports**
-   **Data analytics tool**
-   **Data visualization**
-   **Data analytics**
-   **Angular reporting tool**
-   **Business intelligence**
-   **Angular**
-   **Reporting tool**
-   **Angular report viewer**
-   **Angular report designer**)

[**License Info**](https://github.com/stimulsoft/Reports.JS/blob/HEAD/LICENSE.md)


# Keywords


- **Stimulsoft**
-   **Reports**
-   **Data analytics tool**
-   **Data visualization**
-   **Data analytics**
-   **Angular reporting tool**
-   **Business intelligence**
-   **Angular**
-   **Reporting tool**
-   **Angular report viewer**
-   **Angular report designer**

==> stimulsoft-viewer-angular-2022.4.2.tgz: package/README.md <==
# **Angular component for Stimulsoft Reports**


The Viewer component is designed to view reports in the web browser.

With help of Viewer, you can view, print and export reports on any computer with any operating system installed. Support tablets and smartphones. Also, the viewer supports Mobile interfaces, which automatically enable when using mobile devices and touch screen monitors.

Viewer supports many themes, animated interface, bookmarks, interactive reports, editing of report elements on the page, full screen mode, search panel, and other necessary features for viewing reports.

More about [Stimulsoft Reports.Angular](https://www.stimulsoft.com/en/products/reports-angular)

# How to install

```
npm install stimulsoft-viewer-angular
```
If the Angular version is higher than 9, you should use the command

```
npm install stimulsoft-designer-angular --force
```
# Integration

Stimulsoft Reports.Angular is designed to run in an Angular application with ASP.NET MVC or .NET Core frameworks. For the convenience of integrating the report into the project, a publishing wizard is available.

To integrate the product into the project, it is enough to install the necessary packages from the NPM repository for the Angular project, and one package from the [NuGet repository](https://www.nuget.org/packages/Stimulsoft.Reports.Angular) on the server-side for the required platform. If necessary, all packages can be downloaded from our website to a computer and manually add libraries and scripts to the project. No additional modules or special extensions are required, everything you need you can find in the product

# Live Demo

We prepared many templates of reports and dashboards, that you can explore and edit in our online demo. Choose the template you need, connect your data and try to create rich reports and analytical dashboards – the solution is ready. Try the [**Live Demo**](http://demo.stimulsoft.com/#Js).

# Video and Documentation

We provide full User Manuals and Class References intended to give technical assistance to people using our reporting tools. More information in the [**Online Documentation**](https://www.stimulsoft.com/en/documentation/online/programming-manual/index.html?reports_js.htm)**.**

Also, we prepared many videos about working of our software. See video on our **YouTube channel**.

[**Download**](https://www.stimulsoft.com/en/downloads)

[**Online Store**](https://www.stimulsoft.com/en/# **Angular component for Stimulsoft Reports**

The Angular Designer component is designed to create reports in the web browser.

With help of Angular Designer you can create, edit, save and preview reports on any computer with any operating system installed. Since the designer only uses HTML and JavaScript technologies, it can be run on devices where there is no Flash or Silverlight support - tablets, smartphones. Also, the designer supports the Touch interface, which is automatically enabled when using devices with a touch screen.

The Angular Designer component uses the AJAX technology to perform all actions on reports, which allows you to get rid of reloading the entire page, save Web traffic and speed up work. The report engine built using the .NET Core technology is used to render reports. This is a cross-platform technology. It allows you to deploy the application on servers that use the operating systems like Windows, macOS, and Linux.

More about [Stimulsoft Reports.Angular](https://www.stimulsoft.com/en/products/reports-angular)

# Keywords


- **Stimulsoft**
-   **Reports**
-   **Data analytics tool**
-   **Data visualization**
-   **Data analytics**
-   **Angular reporting tool**
-   **Business intelligence**
-   **Angular**
-   **Reporting tool**
-   **Angular report viewer**
-   **Angular report designer**)

[**License Info**](https://github.com/stimulsoft/Reports.JS/blob/HEAD/LICENSE.md)
